@@ -40,15 +40,15 @@ end
         # Its signature is kwarg_decl(m::Method, kwtype::DataType). The second argument
         # should be the type of the kwsorter from the corresponding MethodTable.
         @test isa(methods(M.j_1), Base.MethodList)
-        @test isdefined(methods(M.j_1), :mt)
-        local mt = methods(M.j_1).mt
+        get_mt(func) = VERSION ≥ v"1.13.0-DEV.647" ? Core.GlobalMethods : methods(func).mt
+        local mt = get_mt(M.j_1)
         @test isa(mt, Core.MethodTable)
         if Base.fieldindex(Core.MethodTable, :kwsorter, false) > 0
             @test isdefined(mt, :kwsorter)
         end
         # .kwsorter is not always defined -- namely, it seems when none of the methods
         # have keyword arguments:
-        @test isdefined(methods(M.f).mt, :kwsorter) === false
+        @test isdefined(get_mt(M.f), :kwsorter) === false
         # M.j_1 has two methods. Fetch the single argument one..
         local m = which(M.j_1, (Any,))
         @test isa(m, Method)
@@ -61,7 +61,7 @@ end
         # that does not have any arguments
         m = which(M.j_1, (Any,Any)) # fetch the no-keyword method
         if VERSION < v"1.4.0-DEV.215"
-            @test Base.kwarg_decl(m, typeof(methods(M.j_1).mt.kwsorter)) == Tuple{}()
+            @test Base.kwarg_decl(m, typeof(get_mt(M.j_1).kwsorter)) == Tuple{}()
         else
             @test Base.kwarg_decl(m) == []
         end
@@ -83,7 +83,9 @@ end
             DSE.format(IMPORTS, buf, doc)
             str = String(take!(buf))
             @test occursin("\n  - `Base`\n", str)
-            @test occursin("\n  - `Core`\n", str)
+            if VERSION < v"1.13-DEV"
+                @test occursin("\n  - `Core`\n", str)
+            end
 
             # Module exports.
             DSE.format(EXPORTS, buf, doc)
